From adff1646c8c5e81d00289e97f19c303c07807bf7 Mon Sep 17 00:00:00 2001
From: Shuicheng Lin <shuicheng.lin@intel.com>
Date: Wed, 12 Feb 2020 15:16:28 +0800
Subject: [PATCH] Fix compile error with gcc-4.8.5

BIT is defined as "(1UL << (nr))", and gcc-4.8.5 cannot recognize
"UL", lead to error message like below:
"
BUILDSTDERR: arch/x86/entry/entry_64.S:1199: Error: found 'L', expected: ')'
BUILDSTDERR: arch/x86/entry/entry_64.S:1199: Error: junk `L<<(0))' after expression
"
Fix it by change BIT(0) to 1 directly in the code.

Signed-off-by: Shuicheng Lin <shuicheng.lin@intel.com>
---
 arch/x86/include/asm/msr-index.h | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/arch/x86/include/asm/msr-index.h b/arch/x86/include/asm/msr-index.h
index d0ba757..936010a 100644
--- a/arch/x86/include/asm/msr-index.h
+++ b/arch/x86/include/asm/msr-index.h
@@ -42,7 +42,7 @@
 /* Intel MSRs. Some also available on other CPUs */
 
 #define MSR_IA32_SPEC_CTRL		0x00000048 /* Speculation Control */
-#define SPEC_CTRL_IBRS			BIT(0)	   /* Indirect Branch Restricted Speculation */
+#define SPEC_CTRL_IBRS			1          /* Indirect Branch Restricted Speculation */
 #define SPEC_CTRL_STIBP_SHIFT		1	   /* Single Thread Indirect Branch Predictor (STIBP) bit */
 #define SPEC_CTRL_STIBP			BIT(SPEC_CTRL_STIBP_SHIFT)	/* STIBP mask */
 #define SPEC_CTRL_SSBD_SHIFT		2	   /* Speculative Store Bypass Disable bit */
-- 
2.7.4

